porerefiner.jobs.submitters package
===================================

Submodules
----------

porerefiner.jobs.submitters.epi2me module
-----------------------------------------

.. automodule:: porerefiner.jobs.submitters.epi2me
   :members:
   :undoc-members:
   :show-inheritance:

porerefiner.jobs.submitters.hpc module
--------------------------------------

.. automodule:: porerefiner.jobs.submitters.hpc
   :members:
   :undoc-members:
   :show-inheritance:

porerefiner.jobs.submitters.local module
----------------------------------------

.. automodule:: porerefiner.jobs.submitters.local
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: porerefiner.jobs.submitters
   :members:
   :undoc-members:
   :show-inheritance:
